document.addEventListener('DOMContentLoaded', () => {
  const fileInput = document.getElementById('fileInput');
  const imagePreview = document.getElementById('imagePreview');
  const analyzeBtn = document.getElementById('analyzeBtn');
  const loader = document.getElementById('loader');
  const resultsContainer = document.getElementById('resultsContainer');
  const resultsContent = document.getElementById('resultsContent');
  
  let selectedFiles = [];

  fileInput.addEventListener('change', (e) => {
    const files = Array.from(e.target.files);
    selectedFiles = files;
    
    // Clear previous previews
    imagePreview.innerHTML = '';
    
    files.forEach(file => {
      if (file.type.startsWith('image/')) {
        const reader = new FileReader();
        reader.onload = (e) => {
          const img = document.createElement('img');
          img.src = e.target.result;
          imagePreview.appendChild(img);
        };
        reader.readAsDataURL(file);
      }
    });
    
    analyzeBtn.disabled = files.length === 0;
  });

  analyzeBtn.addEventListener('click', async () => {
    if (selectedFiles.length === 0) return;

    // Show loader
    loader.style.display = 'block';
    resultsContainer.style.display = 'none';
    
    try {
      // Simulate API calls to AI models
      // In real implementation, you would:
      // 1. Upload images to server
      // 2. Call vision model API
      // 3. Process results with language model API
      await new Promise(resolve => setTimeout(resolve, 2000));
      
      // Sample response
      const analysis = `
        <h3>Medical Document Analysis</h3>
        <p>Based on the uploaded prescription images:</p>
        <ul>
          <li>Medication: [AI detected medication names]</li>
          <li>Dosage: [AI detected dosage information]</li>
          <li>Instructions: [AI generated instructions]</li>
          <li>Precautions: [AI generated precautions]</li>
        </ul>
        <p class="note">Note: This is an AI-generated analysis. Please consult your healthcare provider for medical advice.</p>
      `;
      
      resultsContent.innerHTML = analysis;
      resultsContainer.style.display = 'block';
    } catch (error) {
      resultsContent.innerHTML = `<p class="error">Error analyzing documents. Please try again.</p>`;
      resultsContainer.style.display = 'block';
    } finally {
      loader.style.display = 'none';
    }
  });
});
